/* eslint-disable no-magic-numbers */
import { bioEntitiesContentFixture } from '@/models/fixtures/bioEntityContentsFixture';
import { StoreType } from '@/redux/store';
import { BioEntity } from '@/types/models';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { render, screen } from '@testing-library/react';
import { BioEntitiesPinsListItem } from './BioEntitiesPinsListItem.component';

const BIO_ENTITY = bioEntitiesContentFixture[0].bioEntity;

const renderComponent = (
  name: string,
  pin: BioEntity,
  initialStoreState: InitialStoreState = {},
): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStoreState);

  return (
    render(
      <Wrapper>
        <BioEntitiesPinsListItem name={name} pin={pin} />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('BioEntitiesPinsListItem - component ', () => {
  it('should display name of bio entity element', () => {
    renderComponent(BIO_ENTITY.name, BIO_ENTITY);

    const bioEntityName = BIO_ENTITY.fullName || '';

    expect(screen.getByText(bioEntityName, { exact: false })).toBeInTheDocument();
  });
  it('should display symbol of bio entity element', () => {
    renderComponent(BIO_ENTITY.name, BIO_ENTITY);

    const bioEntitySymbol = BIO_ENTITY.symbol || '';

    expect(screen.getByText(bioEntitySymbol, { exact: false })).toBeInTheDocument();
  });
  it('should display empty string when symbol does not exist', () => {
    const bioEntity = {
      ...bioEntitiesContentFixture[0].bioEntity,
      symbol: null,
    };

    renderComponent(bioEntity.name, bioEntity);

    expect(screen.queryAllByTestId('bio-entity-symbol')).toHaveLength(0);
  });
  it('should display string type of bio entity element', () => {
    renderComponent(BIO_ENTITY.name, BIO_ENTITY);

    const bioEntityStringType = BIO_ENTITY.stringType;

    expect(screen.getByText(bioEntityStringType, { exact: false })).toBeInTheDocument();
  });
  it('should display synonyms of bio entity element', () => {
    renderComponent(BIO_ENTITY.name, BIO_ENTITY);

    const firstBioEntitySynonym = BIO_ENTITY.synonyms[0];
    const secondBioEntitySynonym = BIO_ENTITY.synonyms[1];

    expect(screen.getByText(firstBioEntitySynonym, { exact: false })).toBeInTheDocument();
    expect(screen.getByText(secondBioEntitySynonym, { exact: false })).toBeInTheDocument();
  });
  it('should display list of references for pin', () => {
    renderComponent(BIO_ENTITY.name, BIO_ENTITY);

    const firstPinReferenceType = BIO_ENTITY.references[0].type;
    const firstPinReferenceResource = BIO_ENTITY.references[0].resource;
    const secondPinReferenceType = BIO_ENTITY.references[1].type;
    const secondPinReferenceResource = BIO_ENTITY.references[1].resource;

    expect(screen.getByText(firstPinReferenceType, { exact: false })).toBeInTheDocument();
    expect(screen.getByText(firstPinReferenceResource, { exact: false })).toBeInTheDocument();
    expect(screen.getByText(secondPinReferenceType, { exact: false })).toBeInTheDocument();
    expect(screen.getByText(secondPinReferenceResource, { exact: false })).toBeInTheDocument();
  });
});
